/*
 *  roomba-roam.cc
 * 
 *  Sample code for a robot that has two front bumpers. Suitable for use with
 *  the roomba.
 *
 *  This is example0.cc, changed to (hopefully) make it easier to understand.
 *
 *  Modified: Simon Parsons
 *  Date:     10th September 2009
 *  
 */


#include <iostream>
#include <libplayerc++/playerc++.h>

int main(int argc, char *argv[])
{  
  using namespace PlayerCc;  

  // Variables

  double speed;     // How fast do we want the robot to go forwards?
  double turnrate;  // How fast do we want the robot to turn?

  // Set up proxies. These are the names we will use to connect to 
  // the interface to the robot.

  PlayerClient    robot("localhost");  
  BumperProxy     bp(&robot,0);  
  Position2dProxy pp(&robot,0);

  // Allow the program to take charge of the motors (take care now)
  pp.SetMotorEnable(true);

  // Main control loop
  while(true) 
    {    

      // Read new information from the robot.
      robot.Read();

      // How far do we think we have gone?
      std::cout << pp  << std::endl;

      // Print out what the bumpers tell us:
      std::cout << "Left  bumper: " << bp[0] << std::endl;
      std::cout << "Right bumper: " << bp[1] << std::endl;
      // Can also print the bumpers with:
      //std::cout << bp << std::endl;
      
      // If either bumper is pressed, stop. Otherwise just go forwards

      if(bp[0] || bp[1]){
	speed= 0;
	turnrate= 0;
      } 
      else {
	speed=.1;
        turnrate = 0;
      }     

      // What are we doing?
      //std::cout << pp << std::endl;      
      std::cout << "Speed: " << speed << std::endl;      
      std::cout << "Turn rate: " << turnrate << std::endl << std::endl;

      // Send the commands to the robot
      pp.SetSpeed(speed, turnrate);  
    }
  
}


